/****************************************************************************
** Meta object code from reading C++ file 'mediamonitor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpipewire-6.6.90/src/monitors/mediamonitor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mediamonitor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12MediaMonitorE_t {};
} // unnamed namespace

template <> constexpr inline auto MediaMonitor::qt_create_metaobjectdata<qt_meta_tag_ZN12MediaMonitorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MediaMonitor",
        "QML.Element",
        "auto",
        "roleChanged",
        "",
        "detectionAvailableChanged",
        "countChanged",
        "runningCountChanged",
        "idleCountChanged",
        "connectToCore",
        "onPipeBroken",
        "role",
        "MediaRole::Role",
        "detectionAvailable",
        "count",
        "runningCount",
        "idleCount",
        "Role",
        "StateRole",
        "ObjectSerialRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'roleChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'detectionAvailableChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'runningCountChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'idleCountChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'connectToCore'
        QtMocHelpers::SlotData<void()>(9, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPipeBroken'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'role'
        QtMocHelpers::PropertyData<MediaRole::Role>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'detectionAvailable'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'count'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'runningCount'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'idleCount'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Role'
        QtMocHelpers::EnumData<enum Role>(17, 17, QMC::EnumFlags{}).add({
            {   18, Role::StateRole },
            {   19, Role::ObjectSerialRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MediaMonitor, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN12MediaMonitorE[] = {
    QMetaObject::SuperData::link<MediaRole::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject MediaMonitor::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MediaMonitorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MediaMonitorE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN12MediaMonitorE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12MediaMonitorE_t>.metaTypes,
    nullptr
} };

void MediaMonitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MediaMonitor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->roleChanged(); break;
        case 1: _t->detectionAvailableChanged(); break;
        case 2: _t->countChanged(); break;
        case 3: _t->runningCountChanged(); break;
        case 4: _t->idleCountChanged(); break;
        case 5: _t->connectToCore(); break;
        case 6: _t->onPipeBroken(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MediaMonitor::*)()>(_a, &MediaMonitor::roleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaMonitor::*)()>(_a, &MediaMonitor::detectionAvailableChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaMonitor::*)()>(_a, &MediaMonitor::countChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaMonitor::*)()>(_a, &MediaMonitor::runningCountChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaMonitor::*)()>(_a, &MediaMonitor::idleCountChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<MediaRole::Role*>(_v) = _t->role(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->detectionAvailable(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->rowCount(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->runningCount(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->idleCount(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRole(*reinterpret_cast<MediaRole::Role*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MediaMonitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MediaMonitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MediaMonitorE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int MediaMonitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void MediaMonitor::roleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MediaMonitor::detectionAvailableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MediaMonitor::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MediaMonitor::runningCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MediaMonitor::idleCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
namespace {
struct qt_meta_tag_ZN9MediaRoleE_t {};
} // unnamed namespace

template <> constexpr inline auto MediaRole::qt_create_metaobjectdata<qt_meta_tag_ZN9MediaRoleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MediaRole",
        "QML.Element",
        "auto",
        "Role",
        "Unknown",
        "Movie",
        "Music",
        "Camera",
        "Screen",
        "Communication",
        "Game",
        "Notification",
        "DSP",
        "Production",
        "Accessibility",
        "Test",
        "Last"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Role'
        QtMocHelpers::EnumData<Role>(3, 3, QMC::EnumFlags{}).add({
            {    4, Role::Unknown },
            {    5, Role::Movie },
            {    6, Role::Music },
            {    7, Role::Camera },
            {    8, Role::Screen },
            {    9, Role::Communication },
            {   10, Role::Game },
            {   11, Role::Notification },
            {   12, Role::DSP },
            {   13, Role::Production },
            {   14, Role::Accessibility },
            {   15, Role::Test },
            {   16, Role::Last },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN9MediaRoleE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN9MediaRoleE =
    MediaRole::qt_create_metaobjectdata<qt_meta_tag_ZN9MediaRoleE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN9MediaRoleE =
    qt_staticMetaObjectContent_ZN9MediaRoleE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN9MediaRoleE =
    qt_staticMetaObjectContent_ZN9MediaRoleE.relocatingData;

Q_CONSTINIT const QMetaObject MediaRole::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN9MediaRoleE.stringdata,
    qt_staticMetaObjectStaticContent_ZN9MediaRoleE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN9MediaRoleE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN9NodeStateE_t {};
} // unnamed namespace

template <> constexpr inline auto NodeState::qt_create_metaobjectdata<qt_meta_tag_ZN9NodeStateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NodeState",
        "QML.Element",
        "auto",
        "State",
        "Error",
        "Creating",
        "Suspended",
        "Idle",
        "Running"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<State>(3, 3, QMC::EnumFlags{}).add({
            {    4, State::Error },
            {    5, State::Creating },
            {    6, State::Suspended },
            {    7, State::Idle },
            {    8, State::Running },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN9NodeStateE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN9NodeStateE =
    NodeState::qt_create_metaobjectdata<qt_meta_tag_ZN9NodeStateE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN9NodeStateE =
    qt_staticMetaObjectContent_ZN9NodeStateE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN9NodeStateE =
    qt_staticMetaObjectContent_ZN9NodeStateE.relocatingData;

Q_CONSTINIT const QMetaObject NodeState::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN9NodeStateE.stringdata,
    qt_staticMetaObjectStaticContent_ZN9NodeStateE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN9NodeStateE.metaTypes,
    nullptr
} };

QT_WARNING_POP
