/****************************************************************************
** Meta object code from reading C++ file 'pipewiresourcestream.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kpipewire-6.6.90/src/pipewiresourcestream.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pipewiresourcestream.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20PipeWireSourceStreamE_t {};
} // unnamed namespace

template <> constexpr inline auto PipeWireSourceStream::qt_create_metaobjectdata<qt_meta_tag_ZN20PipeWireSourceStreamE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PipeWireSourceStream",
        "streamReady",
        "",
        "startStreaming",
        "stopStreaming",
        "streamParametersChanged",
        "frameReceived",
        "PipeWireFrame",
        "frame",
        "stateChanged",
        "pw_stream_state",
        "state",
        "oldState"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'streamReady'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startStreaming'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stopStreaming'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'streamParametersChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'frameReceived'
        QtMocHelpers::SignalData<void(const PipeWireFrame &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(pw_stream_state, pw_stream_state)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 10, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PipeWireSourceStream, qt_meta_tag_ZN20PipeWireSourceStreamE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PipeWireSourceStream::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20PipeWireSourceStreamE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20PipeWireSourceStreamE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20PipeWireSourceStreamE_t>.metaTypes,
    nullptr
} };

void PipeWireSourceStream::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PipeWireSourceStream *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->streamReady(); break;
        case 1: _t->startStreaming(); break;
        case 2: _t->stopStreaming(); break;
        case 3: _t->streamParametersChanged(); break;
        case 4: _t->frameReceived((*reinterpret_cast<std::add_pointer_t<PipeWireFrame>>(_a[1]))); break;
        case 5: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<pw_stream_state>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<pw_stream_state>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PipeWireSourceStream::*)()>(_a, &PipeWireSourceStream::streamReady, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireSourceStream::*)()>(_a, &PipeWireSourceStream::startStreaming, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireSourceStream::*)()>(_a, &PipeWireSourceStream::stopStreaming, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireSourceStream::*)()>(_a, &PipeWireSourceStream::streamParametersChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireSourceStream::*)(const PipeWireFrame & )>(_a, &PipeWireSourceStream::frameReceived, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireSourceStream::*)(pw_stream_state , pw_stream_state )>(_a, &PipeWireSourceStream::stateChanged, 5))
            return;
    }
}

const QMetaObject *PipeWireSourceStream::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PipeWireSourceStream::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20PipeWireSourceStreamE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PipeWireSourceStream::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void PipeWireSourceStream::streamReady()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PipeWireSourceStream::startStreaming()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PipeWireSourceStream::stopStreaming()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PipeWireSourceStream::streamParametersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PipeWireSourceStream::frameReceived(const PipeWireFrame & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PipeWireSourceStream::stateChanged(pw_stream_state _t1, pw_stream_state _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}
QT_WARNING_POP
